@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-__version_info__ = (1, 0, 19)
+__version_info__ = (1, 0, 20)
 __version__ = '.'.join(str(i) for i in __version_info__)
 
 import re
@@ -432,7 +432,7 @@ class Parser (object):
                 if not match:
                     break
                 # Replace any link with a token that we can substitute back in after replacements.
-                token = '{{ bbcode-link-%s }}' % id(match)
+                token = '{{ bbcode-link-%s }}' % len(url_matches)
                 url_matches[token] = self._link_replace(match, **context)
                 start, end = match.span()
                 data = data[:start] + token + data[end:]
